% MONOPOLY PROBLEM--Main Program
% main.m
% Numerical Methods for Macroeconomists, by Jeremy Greenwood and Ricardo 
% Marto, Copywrite, Jeremy Greenwood

clear all % Clear all numbers from previous runs
clc       % Clear screen 
global alpha beta gamma

% Set parameters for model

% Demand curve
alpha = 1; % constant
beta  = 0.5; % slope
% Cost function
gamma = 0.5; % quadratic term

% Plot marginal revenue and marginal cost

% Construct grid of output points
ogrid = 0:alpha/(beta*100):alpha/beta;
% ogrid runs from 0 to alpha/beta in 
% increments of alpha/(beta*100)

% Plot marginal revenue and cost curves
% Note the use of the FontSize command to get the graph's labels 
% to look nice
figure(1)
plot(ogrid,mr(ogrid),ogrid,mc(ogrid))
title('Marginal Revenue and Marginal Cost', 'FontSize', 17)
xlabel('Output','FontSize', 15)
ylabel('MR and MC','FontSize', 15)

% Solve for output and prices

output = fzero(@foc,.5);  % Call up nonlinear equation solver
% Check solution gives a zero
if abs( foc(output) ) >=.000001
    disp('solution not found')
end
price  = alpha - beta*output/2;
cost   = gamma*output^2/2;
profits = price*output - cost;
markup = price/mc(output);

% Display results

disp ('Results for the monopoly model')
disp ('output, price, profits, and markup')
disp ([output price profits markup])

%% Table 

% Put data for MR and MC in a table
oput = ogrid';
MarRev = mr(ogrid)';
MarCost= mc(ogrid)';
T = table(oput,MarRev,MarCost,'VariableNames',{'Output' 'MR' 'MC'});
%% Excel 

% Export the table to an EXCEL file
filename = 'Monopoly.xlsx';
writetable(T,filename)   
