% PLOT UTILITY FUNCTIONS
% utilityfuncs.m
% Numerical Methods for Macroeconomists, by Jeremy Greenwood and Ricardo 
% Marto, Copywrite, Jeremy Greenwood

clear all                                % Clear everything from memory

%% Generate a grid for consumption going from .1 to 3 by increments of .05
% This will be a vector of 59 points
cons = .1:.05:3;

%% Plot the utility functions
% Note the use of the FontSize command to get the graph's labels 
% to look nice

% Logarithmic utility function
figure(1)                                % Command to open figure window 1
lnutil = log(cons);                      % Generate vector of utils 
plot(cons,lnutil)                        % Plot cons and utils
title('Log Utility','FontSize',18)       % Make title  
ylabel('Utils, u','FontSize',15)         % Make label for vertical axis 
xlabel('Consumption, c','FontSize',15)   % Make label for horizontal axis 

% Exponential utility function
figure(2)
gamma = 1.0;                             % Parameter for exponential 
exputil = -exp(-gamma*cons);
plot(cons, exputil)
title('Exponential Utility','FontSize',18)
ylabel('Utils, u','FontSize',15)
xlabel('Consumption, c','FontSize',15)

% CRRA utility function
figure(3)
rho = 1.5;                               % Parameter for crra 
crrautil = cons.^(1-rho)/(1-rho) - 1/(1-rho) ;
plot(cons, crrautil)
title('Isoelastic Utility','FontSize',18)
ylabel('Utils, u', 'FontSize',15)
xlabel('Consumption, c', 'FontSize',15)

% Quadratic utility function
figure(4)
alpha = .5;                              % Coefficients for quadratic terms
beta = .2;
quadutil = alpha*cons - beta*cons.^2/2;
% Create vertical line where quadratic utility function peaks
maxpty = 0:.7/58:.7;                  % Generate vertical y points 
% Generate x vector with the constant term alpha/beta
maxptx = ones(1,59)*alpha/beta;       % Generate x vector with the constant 
% Plot utility function plus vertical line
plot(cons, quadutil, maxptx, maxpty)
title('Quadratic Utility','FontSize',18)              
ylabel('Utils, u','FontSize',15)
xlabel('Consumption, c','FontSize',15)

% Plot all utility functions
figure(5)
plot(cons',lnutil',cons', exputil',cons', crrautil',cons',quadutil')
title('Utility Functions','FontSize',18)
ylabel('Utils, u','FontSize',15)
xlabel('Consumption, c','FontSize',15)
% Make a legend in the southeast corner of the graph. 
legend('log','exp','crra','quadratic','location','southeast' )

%% Collect data for alternative graphing package

data = [cons',lnutil',exputil',crrautil',quadutil'];
% The matrix data can be copied from directly from the workspace and then
% be pasted into EXCEL or another program
% Exporting Data in a Table Format
% Alternatively one could create a table and export the table to EXCEL
% Construct variables for table in column format
consump = cons';
uln   = lnutil';
uexp  = exputil';
ucrra = crrautil';
uquad = quadutil';
% Create the table
T = table(consump,uln,uexp,ucrra,uquad);
% Export the table to an EXCEL file
filename = 'UtilityData.xlsx';
writetable(T,filename)